# Generated by Django 4.2 on 2023-04-26 11:04

from django.db import migrations, models
import django.db.models.deletion
import django_bleach.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
    ]

    operations = [
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=64)),
                ('title', models.CharField(max_length=128)),
                ('description', models.CharField(blank=True, max_length=256)),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='sites.site')),
            ],
            options={
                'unique_together': {('site', 'key')},
            },
        ),
        migrations.CreateModel(
            name='Text',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content', django_bleach.models.BleachField()),
                ('key', models.CharField(max_length=64)),
                ('page', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='drf_cms.page')),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='sites.site')),
            ],
            options={
                'unique_together': {('site', 'page', 'key')},
            },
        ),
    ]
